@@ -1,38 +1,38 @@
 #' Diagnostical Statistics
-#' 
+#'
 #' The \code{udg} function provides access to a large number of diagnostical
-#' statistics. The \code{qs} function and the \code{AIC}, \code{BIC} and 
-#' \code{logLik} methods are  wrappers that use \code{udg} to access some 
+#' statistics. The \code{qs} function and the \code{AIC}, \code{BIC} and
+#' \code{logLik} methods are  wrappers that use \code{udg} to access some
 #' specific diagnostical statistics.
-#' 
+#'
 #' @param x,object  an object of class \code{"seas"}.
-#' @param stats  character vector; if specified, only a subset of the available 
-#'   stats are returned. This speeds up the call, as only a subset needs to be 
+#' @param stats  character vector; if specified, only a subset of the available
+#'   stats are returned. This speeds up the call, as only a subset needs to be
 #'   type converted. Should be used for programming.
-#' @param simplify  logical; should the result be simplified to a vector or 
+#' @param simplify  logical; should the result be simplified to a vector or
 #'   matrix, if possible?
-#' @param fail   logical; if \code{TRUE}, an error is droped if an element of 
+#' @param fail   logical; if \code{TRUE}, an error is droped if an element of
 #'   \code{stats} is missing in \code{names(udg(x))}.
 #' @param ...   further arguments (not used)
 #' @return  \code{qs} returns the QS statistics for seasonality of input and
 #'   output series and the corresponding p-values.
-#' @return  \code{AIC}, \code{BIC}, \code{nobs} and \code{logLik} return the 
+#' @return  \code{AIC}, \code{BIC}, \code{nobs} and \code{logLik} return the
 #'   corresponding statistics.
-#' 
+#'
 #' @seealso \code{\link{seas}} for the main function.
 #' @seealso \code{\link{series}}, for universal X-13 output extraction.
 #' @seealso \code{\link{plot.seas}}, for diagnostical plots.
 #' @seealso \code{\link{out}}, for accessing the full output of X-13ARIMA-SEATS.
-#' 
-#' @references Vignette with a more detailed description: 
+#'
+#' @references Vignette with a more detailed description:
 #'   \url{http://www.seasonal.website/seasonal.html}
-#'   
-#'   Comprehensive list of R examples from the X-13ARIMA-SEATS manual: 
+#'
+#'   Comprehensive list of R examples from the X-13ARIMA-SEATS manual:
 #'   \url{http://www.seasonal.website/examples.html}
-#'   
-#'   Official X-13ARIMA-SEATS manual: 
+#'
+#'   Official X-13ARIMA-SEATS manual:
 #'   \url{https://www.census.gov/ts/x13as/docX13ASHTML.pdf}
-#' 
+#'
 #' @export
 #' @examples
 #' \dontrun{
@@ -73,7 +73,7 @@ udg <- function(x, stats = NULL, simplify = TRUE, fail = TRUE){
     xx <- xx[stats]
   }
 
-  z <- lapply(xx, function(e) type.convert(e))
+  z <- lapply(xx, function(e) type.convert(e, as.is = FALSE))
 
   # factors to character
   is.char <- sapply(z, inherits, "factor")
@@ -85,16 +85,16 @@ udg <- function(x, stats = NULL, simplify = TRUE, fail = TRUE){
     zc <- z[is.char]
     is.long <- grepl("\\d+ +.", zc)
 
-    ## exclude false positives 
+    ## exclude false positives
     # ARIMA models
     is.long[is.long] <- !grepl("\\(", zc[is.long])
     # time spans
     is.long[grepl("span$", names(zc))] <- FALSE
-    
+
     # split at spaces and convert to numeric
     if (any(is.long)){
       lsplit <- strsplit(as.character(zc[is.long]), split = " +")
-      ll <- lapply(lsplit, type.convert)
+      ll <- lapply(lsplit, type.convert, as.is = FALSE)
       ll[sapply(ll, inherits, "factor")] <- lapply(ll[sapply(ll, inherits, "factor")], as.character)
 
       names(ll) <- names(zc[is.long])
